/* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */

#include "NoWeapon.h"
#include "WeaponMemPool.h"

CR_BIND_DERIVED_POOL(CNoWeapon, CWeapon, , weaponMemPool.alloc, weaponMemPool.free)
CR_REG_METADATA(CNoWeapon, )

